<?php
include("sqlcfg.php");

function dbCreateTables($conn) {	
	$conn->query("CREATE TABLE IF NOT EXISTS Users(Id INT NOT NULL AUTO_INCREMENT, Username TEXT, PasswordHash TEXT, PRIMARY KEY(Id))");
	$conn->query("CREATE TABLE IF NOT EXISTS Systems(Id INT NOT NULL AUTO_INCREMENT, Name TEXT, IsPluralSystem BOOL, SubSystem INT, UserCreated INT, PRIMARY KEY(Id))");
	$conn->query("CREATE TABLE IF NOT EXISTS Members(Id INT NOT NULL AUTO_INCREMENT, Name TEXT, Pronouns TEXT, FromSystem INT, PRIMARY KEY(Id))");
}


function dbConnect(){
	$conn = new mysqli(MYSQL_HOST, MYSQL_USERNAME, MYSQL_PASSWORD, MYSQL_DATABASE);
	
	
	if ($conn->connect_error) {
		echo("<b>connection to mysql database failed.</b>");
		exit();
	}
	
	
	dbCreateTables($conn);
	
	return $conn;
}


function dbGetPasswordHash(string $username){
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT PasswordHash FROM Users WHERE Username=?");
	$prep->bind_param("s", $username);
	$prep->execute();

	return $prep->get_result()->fetch_row()[0];
}

function dbGetUserName(int $userId) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT Username FROM Users WHERE Id=?");
	$prep->bind_param("i", $userId);
	
	$prep->execute();
	return $prep->get_result()->fetch_row()[0];
}

function dbGetUserId(string $username) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT Id FROM Users WHERE Username=?");
	$prep->bind_param("s", $username);
	
	$prep->execute();
	return intval($prep->get_result()->fetch_row()[0]);
}

function dbUserExist(string $username) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT COUNT(*) FROM Users WHERE Username=?");
	$prep->bind_param("s", $username);
	
	$prep->execute();
	return intval($prep->get_result()->fetch_row()[0]);
}

function dbCreateUser(string $username, string $password)	{
	
	$hashedPassword = password_hash($password, PASSWORD_BCRYPT);
	$conn = dbConnect();
	$prep = $conn->prepare("INSERT INTO Users VALUES(NULL, ?, ?)");
	$prep->bind_param("ss", $username, $hashedPassword);
	$prep->execute();
	
}

function dbGetSystems(int $userId) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT * FROM Systems WHERE UserCreated=?");
	$prep->bind_param("i", $userId);
	
	$prep->execute();
	return $prep->get_result()->fetch_all();
}


function dbGetMemberCount(int $systemId) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT COUNT(*) FROM Members WHERE FromSystem=?");
	$prep->bind_param("i", $systemId);
	
	$prep->execute();
	return intval($prep->get_result()->fetch_row()[0]);
}

function dbGetMembers(int $systemId) {
	$conn = dbConnect();
	$prep = $conn->prepare("SELECT * FROM Members WHERE FromSystem=?");
	$prep->bind_param("i", $systemId);
	
	$prep->execute();
	return $prep->get_result()->fetch_all();
}

function dbCreateSystem(string $systemName, bool $isPlural, $subSystem, int $userId) {
	
	$conn = dbConnect();
	$prep = $conn->prepare("INSERT INTO Systems VALUES(NULL, ?, ?, ?, ?)");
	$prep->bind_param("siii", $systemName, $isPlural, $subSystem, $userId);
	$prep->execute();
	
}

function dbCreateMember(string $memberName, string $pronouns, int $fromSystem) {
	
	$conn = dbConnect();
	$prep = $conn->prepare("INSERT INTO Members VALUES(NULL, ?, ?, ?)");
	$prep->bind_param("ssi", $memberName, $pronouns, $fromSystem);
	$prep->execute();
	
}


?>